import React, { useState } from 'react';
import Logo from '../components/Logo';
import AudioRecorder from '../components/AudioRecorder';
import TranscriptionField from '../components/TranscriptionField';
import CopyButton from '../components/CopyButton';
import LoadingSpinner from '../components/LoadingSpinner';
import ErrorMessage from '../components/ErrorMessage';
import './RecordPage.css';

function RecordPage() {
  const [transcription, setTranscription] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState('');

  const handleTranscriptionComplete = (text) => {
    setIsLoading(false);
    setTranscription(text);
    setError('');
  };

  const handleTranscriptionStart = () => {
    setIsLoading(true);
    setError('');
  };

  const handleTranscriptionError = (errorMessage) => {
    setIsLoading(false);
    setError(errorMessage);
    console.error('Transcription error:', errorMessage);
  };

  return (
    <div className="record-page">
      <Logo />
      <div className="record-content">
        <AudioRecorder 
          onTranscriptionComplete={handleTranscriptionComplete}
          onTranscriptionStart={handleTranscriptionStart}
          onError={handleTranscriptionError}
        />
        
        <LoadingSpinner isVisible={isLoading} />
        
        <ErrorMessage 
          message={error}
          onDismiss={() => setError('')}
        />
        
        <TranscriptionField transcription={transcription} />
        
        <CopyButton text={transcription} />
      </div>
    </div>
  );
}

export default RecordPage;

