import OpenAI from 'openai';

const openai = new OpenAI({
  apiKey: process.env.REACT_APP_OPENAI_API_KEY,
  dangerouslyAllowBrowser: true, // Only for dev & testing
});

export const transcribeAudio = async (audioBlob) => {
  try {
    console.log('Transcribing audio with Whisper...');
    // Create a File from the blob with webm format for better compatibility
    const file = new File([audioBlob], 'recording.webm', { type: 'audio/webm' });

    // Send to Whisper API for transcription
    const transcription = await openai.audio.transcriptions.create({
      file,
      model: 'whisper-1',
      response_format: 'json',
    });

    console.log('Whisper transcription received:', transcription);
    return transcription.text;
  } catch (error) {
    console.error('Whisper API error:', error);
    throw new Error('Failed to transcribe audio. Please try again.');
  }
};
